from setuptools import setup

setup(name='auxiliary_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['auxiliary_distributions'],
      zip_safe=False)
